@@ -81,7 +81,8 @@ pub async fn globset(args: &ArgMatches<'static>) -> Result<Arc<WatchexecFilterer
 		.values_of_os("extensions")
 		.unwrap_or_default()
 		.map(|s| s.split(b','))
-		.flatten();
+		.flatten()
+		.map(|e| os_strip_prefix(e, b'.'));
 
 	Ok(Arc::new(WatchexecFilterer {
 		inner: GlobsetFilterer::new(project_origin, filters, ignores, ignore_files, exts)
@@ -157,6 +158,17 @@ impl Iterator for OsSplit {
 	}
 }
 
+#[cfg(unix)]
+fn os_strip_prefix(os: OsString, prefix: u8) -> OsString {
+	use std::os::unix::ffi::{OsStrExt, OsStringExt};
+	let bytes = os.as_bytes();
+	if bytes.first().copied() == Some(prefix) {
+		OsString::from_vec(bytes[1..].to_vec())
+	} else {
+		os
+	}
+}
+
 #[cfg(windows)]
 impl Iterator for OsSplit {
 	type Item = OsString;
@@ -183,11 +195,25 @@ impl Iterator for OsSplit {
 	}
 }
 
+#[cfg(windows)]
+fn os_strip_prefix(os: OsString, prefix: u8) -> OsString {
+	use std::os::windows::ffi::{OsStrExt, OsStringExt};
+	let wides: Vec<u16> = os.encode_wide().collect();
+	if wides.first().copied() == Some(u16::from(prefix)) {
+		OsString::from_wide(&wides[1..])
+	} else {
+		os
+	}
+}
+
 #[cfg(test)]
 #[test]
 fn os_split_none() {
 	let os = OsString::from("");
-	assert_eq!(os.split(b',').collect::<Vec<OsString>>(), Vec::<OsString>::new());
+	assert_eq!(
+		os.split(b',').collect::<Vec<OsString>>(),
+		Vec::<OsString>::new()
+	);
 
 	let mut split = os.split(b',');
 	assert_eq!(split.next(), None);
@@ -197,7 +223,10 @@ fn os_split_none() {
 #[test]
 fn os_split_one() {
 	let os = OsString::from("abc");
-	assert_eq!(os.split(b',').collect::<Vec<OsString>>(), vec![OsString::from("abc")]);
+	assert_eq!(
+		os.split(b',').collect::<Vec<OsString>>(),
+		vec![OsString::from("abc")]
+	);
 
 	let mut split = os.split(b',');
 	assert_eq!(split.next(), Some(OsString::from("abc")));
@@ -208,11 +237,14 @@ fn os_split_one() {
 #[test]
 fn os_split_multi() {
 	let os = OsString::from("a,b,c");
-	assert_eq!(os.split(b',').collect::<Vec<OsString>>(), vec![
-		OsString::from("a"),
-		OsString::from("b"),
-		OsString::from("c"),
-	]);
+	assert_eq!(
+		os.split(b',').collect::<Vec<OsString>>(),
+		vec![
+			OsString::from("a"),
+			OsString::from("b"),
+			OsString::from("c"),
+		]
+	);
 
 	let mut split = os.split(b',');
 	assert_eq!(split.next(), Some(OsString::from("a")));
@@ -225,12 +257,15 @@ fn os_split_multi() {
 #[test]
 fn os_split_leading() {
 	let os = OsString::from(",a,b,c");
-	assert_eq!(os.split(b',').collect::<Vec<OsString>>(), vec![
-		OsString::from(""),
-		OsString::from("a"),
-		OsString::from("b"),
-		OsString::from("c"),
-	]);
+	assert_eq!(
+		os.split(b',').collect::<Vec<OsString>>(),
+		vec![
+			OsString::from(""),
+			OsString::from("a"),
+			OsString::from("b"),
+			OsString::from("c"),
+		]
+	);
 
 	let mut split = os.split(b',');
 	assert_eq!(split.next(), Some(OsString::from("")));
@@ -239,3 +274,53 @@ fn os_split_leading() {
 	assert_eq!(split.next(), Some(OsString::from("c")));
 	assert_eq!(split.next(), None);
 }
+
+#[cfg(test)]
+#[test]
+fn os_strip_none() {
+	let os = OsString::from("abc");
+	assert_eq!(
+		os_strip_prefix(os, b'.'),
+		OsString::from("abc")
+	);
+}
+
+#[cfg(test)]
+#[test]
+fn os_strip_left() {
+	let os = OsString::from(".abc");
+	assert_eq!(
+		os_strip_prefix(os, b'.'),
+		OsString::from("abc")
+	);
+}
+
+#[cfg(test)]
+#[test]
+fn os_strip_not_right() {
+	let os = OsString::from("abc.");
+	assert_eq!(
+		os_strip_prefix(os, b'.'),
+		OsString::from("abc.")
+	);
+}
+
+#[cfg(test)]
+#[test]
+fn os_strip_only_left() {
+	let os = OsString::from(".abc.");
+	assert_eq!(
+		os_strip_prefix(os, b'.'),
+		OsString::from("abc.")
+	);
+}
+
+#[cfg(test)]
+#[test]
+fn os_strip_only_once() {
+	let os = OsString::from("..abc");
+	assert_eq!(
+		os_strip_prefix(os, b'.'),
+		OsString::from(".abc")
+	);
+}
